@@ -44,7 +44,7 @@ function filter($res, $dd)
 
 	foreach ($header as $key => $val) {
 		if (count($data)>0) {
-			$field_type = mysql_field_type($data, $field_offset);
+			$field_type =  mysqli_fetch_field_direct($data, $field_offset);
 		} else {
 			$field_type = 'string';
 		}
@@ -197,7 +197,7 @@ function filter($res, $dd)
 	}
 
 	$res_count = 0;
-	while ($rec = mysql_fetch_assoc($data)) {
+	while ($rec = mysqli_fetch_assoc($data)) {
 		$row = array();
 		foreach ($rec as $key => $val) {
 			$null_val = false;
